#!/bin/bash
#
######################################################################
#
#	install.com.samisit.noatime.launchdaemon.sh
#
#	Samuel Herschbein
#	sam@SamIsIT.com
#	sherschbein@me.com
#
#	Script to install a LaunchDaemon that sets noatime on mounted HFS & APFS volumes.
#
#	Details and Revision History are in README.txt
#
######################################################################
#
#	Get the script's name.
thisScriptName="${0##*/}"
#	Get the script's path with trailing slash.
thisScriptPath="${0%/*}/"
#
#	Script must be run with sudo.
[[ "$(whoami)" != "root" ]] && { printf "$thisScriptName must be run with sudo.\n\n"; exit; }
#
#	Inform & quit if launch daemon already running (bootstrapped).
launchctlResult="$(sudo launchctl print system | grep 'com.samisit.noatime.launchdaemon' | awk '{print $3}')"
[[ "$launchctlResult" != "" ]] && { printf "\ncom.samisit.noatime.launchdaemon Launch Daemon already running, quitting.\n\n"; exit; }
#
#	Make sure both the plist is in same directory as this script.
[[ ! -f "${thisScriptPath}com.samisit.noatime.launchdaemon.plist" ]] && { printf "File ${thisScriptPath}com.samisit.noatime.launchdaemon.plist not found.\n\n"; exit; }
#
#	Copy the plist, then set ownership & permissions.
cp "${thisScriptPath}com.samisit.noatime.launchdaemon.plist" /Library/LaunchDaemons
chown root:wheel /Library/LaunchDaemons/com.samisit.noatime.launchdaemon.plist
chmod 644 /Library/LaunchDaemons/com.samisit.noatime.launchdaemon.plist
#
#	Bootstrap the LaunchDaemon.
launchctlError="$(launchctl bootstrap system /Library/LaunchDaemons/com.samisit.noatime.launchdaemon.plist 2>&1)"
if [[ "$?" -ne 0 ]]; then
	printf "\n%s\n\n" "Error bootstrapping com.samisit.noatime.launchdaemon: ${launchctlError##*: }."
	exit
else
	printf "\n%s\n\n" "com.samisit.noatime.launchdaemon LaunchDaemon was bootstrapped successfully."
fi
#
